@@ -2,8 +2,6 @@ pub mod device;
 mod executor;
 mod waker;
 
-#[cfg(target_arch = "aarch64")]
-use aarch64::regs::*;
 #[cfg(target_arch = "x86_64")]
 use std::arch::x86_64::_rdtsc;
 use std::ops::DerefMut;
@@ -11,9 +9,12 @@ use std::str::FromStr;
 use std::sync::atomic::{AtomicU16, Ordering};
 use std::sync::Mutex;
 use std::task::{Context, Poll};
-
 use std::u16;
 
+#[cfg(target_arch = "aarch64")]
+use aarch64::regs::*;
+use futures_lite::future;
+use lazy_static::lazy_static;
 #[cfg(feature = "dhcpv4")]
 use smoltcp::dhcp::Dhcpv4Client;
 use smoltcp::phy::Device;
@@ -25,8 +26,8 @@ use smoltcp::wire::IpAddress;
 #[cfg(feature = "dhcpv4")]
 use smoltcp::wire::{IpCidr, Ipv4Address, Ipv4Cidr};
 use smoltcp::Error;
-
-use futures_lite::future;
+#[cfg(target_arch = "aarch64")]
+use tock_registers::interfaces::Readable;
 
 use crate::net::device::HermitNet;
 use crate::net::executor::{block_on, poll_on, spawn};
@@ -258,11 +259,14 @@ impl AsyncSocket {
 				| TcpState::TimeWait => Poll::Ready(Err(Error::Illegal)),
 				_ => {
 					if s.may_recv() {
-						Poll::Ready(s.recv_slice(buffer))
-					} else {
-						s.register_recv_waker(cx.waker());
-						Poll::Pending
+						let n = s.recv_slice(buffer)?;
+						if n > 0 || buffer.is_empty() {
+							return Poll::Ready(Ok(n));
+						}
 					}
+
+					s.register_recv_waker(cx.waker());
+					Poll::Pending
 				}
 			})
 		})
@@ -480,8 +484,14 @@ pub fn sys_tcp_stream_peek(_handle: Handle, _buf: &mut [u8]) -> Result<usize, ()
 }
 
 #[no_mangle]
-pub fn sys_tcp_stream_set_nonblocking(_handle: Handle, _mode: bool) -> Result<(), ()> {
-	Err(())
+pub fn sys_tcp_stream_set_nonblocking(_handle: Handle, mode: bool) -> Result<(), ()> {
+	// non-blocking mode is currently not support
+	// => return only an error, if `mode` is defined as `true`
+	if mode {
+		Err(())
+	} else {
+		Ok(())
+	}
 }
 
 #[no_mangle]
